/*
 * burtUtil.c
 *
 *    This file implements utilities used by more than one module in Burt
 *
 * Copyright (C) 1995 - 1998 Eric Melski and Dean Jansa
 *
 * Permission to use, copy, modify and distribute this software and its
 * documentation for any purpose is hereby granted without fee, provided that
 * the above copyright notice and this permission notice appear in all copies,
 * and that all support documentation is included with each copy of the software.
 * A reasonable copying fee may be charged for any distribution of this 
 * software, but no fee may be charged for the software itself. You may 
 * distribute this software in aggregate with other programs as part of a 
 * larger software distribution provided that this software is not advertised 
 * as a product of your own.  Eric Melski and Dean Jansa make no representations
 * about the suitability of this software for any purpose.  It is provided 
 * "as is" without express or implied warranty.
 *
 * ERIC MELSKI AND DEAN JANSA DISCLAIM ALL WARRANTIES WITH REGARD TO THIS
 * SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS.
 * IN NO EVENT SHALL ERIC MELSKI OR DEAN JANSA BE LIABLE FOR ANY SPECIAL,
 * INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
 * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
 * OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THIS SOFTWARE.
 *
 */


#ifndef lint
static char rcsid[] = "$Id: burtUtil.c,v 1.4 1998/08/18 20:39:45 jmelski Exp $";
#endif

#include <burtInt.h>
/*
 *----------------------------------------------------------------------
 *
 * BurtTableLength --
 *
 *	This procedure returns the number of items in the table.
 *
 * Results:
 *	Returns the number of schdule items in the table.
 *
 * Side effects:
 *
 *----------------------------------------------------------------------
 */

int
BurtTableLength(Tcl_HashTable *tablePtr)
{
    Tcl_HashEntry *entryPtr;
    Tcl_HashSearch search;
    int length;

    length = 0;
    entryPtr = Tcl_FirstHashEntry(tablePtr, &search);
    while (entryPtr != NULL) {
	length++;
	entryPtr = Tcl_NextHashEntry(&search);
    }

    return(length);
}

/*
 *----------------------------------------------------------------------
 *
 * BurtTime --
 *
 *      Generates a standard Burt timestamp in some static memory. 
 *      
 * Results:
 *      
 *      Returns a pointer to the timestamp.
 *	
 * Side effects:
 *      
 *      Wipes out whatever existed at the spot before.
 *      
 *----------------------------------------------------------------------
 */

char *
BurtTime(void)
{
  time_t timer;
  static char now[32];

  timer = time((time_t *)NULL);
  strftime(now, 32, "%X %x", localtime(&timer));
  return(now);
}


